@@ -115,7 +115,7 @@ struct key_params {
 	.n = _n, .len_n = sizeof(_n),	\
 }
 
-static const struct key_params keys[] = {
+static const struct key_params __attribute__ ((unused)) keys[] = {
 ''')
     for n in xrange(n + 1):
         output.write('	KEYS(e_%d, n_%d),\n' % (n, n))
